@@ -211,6 +211,13 @@
 	  (slot-value a 'loc))))
   10 10 "subloc-1" "a subloc")
 
+(deftest :oodml/select/23
+    (with-dataset *ds-artists*
+      (length (clsql:select 'artist :flatp t :caching nil)))
+  0)
+
+
+
 ;; test retrieval is deferred
 (deftest :oodm/retrieval/1
     (with-dataset *ds-employees*
@@ -299,15 +306,16 @@
 ;; tests update-record-from-slot
 (deftest :oodml/update-records/2
     (with-dataset *ds-employees*
+      ;(start-sql-recording :type :both)
       (values
 	(employee-email
 	 (car (clsql:select 'employee
 			    :where [= 1 [slot-value 'employee 'emplid]]
 			    :flatp t
 			    :caching nil)))
-	(progn
-	  (setf (slot-value employee1 'email) "lenin-nospam@soviet.org")
-	  (clsql:update-record-from-slot employee1 'email)
+ 	(progn
+ 	  (setf (slot-value employee1 'email) "lenin-nospam@soviet.org")
+ 	  (clsql:update-record-from-slot employee1 'email)
 	  (employee-email
 	   (car (clsql:select 'employee
 			      :where [= 1 [slot-value 'employee 'emplid]]
@@ -546,6 +554,8 @@
 	       (let ((sl (car (clsql:select 'subloc
 					    :where [= 10 [slot-value 'subloc 'subloc-id]]
 					    :flatp t :caching nil))))
+		 (unless sl
+		   (error "Couldn't find expected sublocation"))
 		 (format nil "~a ~a ~a"
 			 (slot-value sl 'subloc-id)
 			 (slot-value sl 'title)
@@ -568,6 +578,8 @@
 	       (let ((sl (car (clsql:select 'subloc
 					    :where [= 10 [slot-value 'subloc 'subloc-id]]
 					    :flatp t :caching nil))))
+		 (unless sl
+		   (error "In psfl: found no sublocation with id = 10"))
 		 (format nil "~a ~a ~a"
 			 (slot-value sl 'subloc-id)
 			 (slot-value sl 'title)
@@ -577,6 +589,8 @@
 	  (let ((sl (car (clsql:select 'subloc
 				       :where [= 10 [slot-value 'subloc 'subloc-id]]
 				       :flatp t :caching nil))))
+	    (unless sl
+	      (error "Select for modification: Found no sublocation with id = 10"))
 	    (setf (slot-value sl 'title) "Altered subloc title")
 	    (setf (slot-value sl 'loc) "Altered loc")
 	    (clsql:update-record-from-slot sl 'title)
@@ -585,9 +599,11 @@
 	  (let ((sl (car (clsql:select 'subloc
 				       :where [= 10 [slot-value 'subloc 'subloc-id]]
 				       :flatp t :caching nil))))
+	    (unless sl
+	      (error "Select for next modification: Found no sublocation with id = 10"))
 	    (setf (slot-value sl 'title) "subloc-1")
 	    (setf (slot-value sl 'loc) "a subloc")
-	    (clsql:update-record-from-slot sl '(title loc))
+	    (clsql:update-record-from-slots sl '(title loc))
 	    (print-fresh-subloc)))))
   "10 subloc-1 a subloc"
   "10 Altered subloc title Altered loc"
@@ -614,6 +630,17 @@
   ((42.0d0))
   ((24.13d0)))
 
+(deftest :oodml/update-records/11
+    (with-dataset *ds-artists*
+      (clsql:update-records-from-instance artist1)
+      (list (name artist1) (artist_id artist1)))
+  ("Mogwai" 1))
+
+(deftest :oodml/update-records/12
+    (with-dataset *ds-artists*
+      (clsql:update-records-from-instance artist1)
+      (list (name artist1) (genre artist1)))
+  ("Mogwai" "Unknown"))
 
 ;; tests update-instance-from-records
 (deftest :oodml/update-instance/1
